summaryrefslogtreecommitdiffstats
path: root/demos/engines/zencod/hw_zencod.c
diff options
context:
space:
mode:
authorRich Salz <rsalz@akamai.com>2015-10-27 15:11:48 -0400
committerRich Salz <rsalz@openssl.org>2015-10-30 17:21:42 -0400
commitb0700d2c8de79252ba605748a075cf2e5d670da1 (patch)
tree80d8b70286dfab4ef907cf1ac388f691821b0f2e /demos/engines/zencod/hw_zencod.c
parent87d9cafa332bd006086b56dc645c03fe7cfed654 (diff)
Replace "SSLeay" in API with OpenSSL
All instances of SSLeay (any combination of case) were replaced with the case-equivalent OpenSSL. Reviewed-by: Richard Levitte <levitte@openssl.org>
Diffstat (limited to 'demos/engines/zencod/hw_zencod.c')
-rw-r--r--demos/engines/zencod/hw_zencod.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/demos/engines/zencod/hw_zencod.c b/demos/engines/zencod/hw_zencod.c
index 5f5098083c..132ece04f0 100644
--- a/demos/engines/zencod/hw_zencod.c
+++ b/demos/engines/zencod/hw_zencod.c
@@ -309,14 +309,14 @@ static int bind_helper(ENGINE *e)
}
# ifndef OPENSSL_NO_RSA
/*
* We know that the "PKCS1_SSLeay()" functions hook properly to the
* Zencod-specific mod_exp and mod_exp_crt so we use those functions. NB:
* We don't use ENGINE_openssl() or anything "more generic" because
* something like the RSAref code may not hook properly, and if you own
* one of these cards then you have the right to do RSA operations on it
* anyway!
*/
- meth_rsa = RSA_PKCS1_SSLeay();
+ meth_rsa = RSA_PKCS1_OpenSSL();
zencod_rsa.rsa_pub_enc = meth_rsa->rsa_pub_enc;
zencod_rsa.rsa_pub_dec = meth_rsa->rsa_pub_dec;
@@ -358,9 +358,9 @@ static int bind_helper(ENGINE *e)
# endif
/*
- * We use OpenSSL (SSLeay) meth to supply what we don't provide ;-*)
+ * We use OpenSSL meth to supply what we don't provide ;-*)
*/
- meth_rand = RAND_SSLeay();
+ meth_rand = RAND_OpenSSL();
/* meth_rand->seed ; */
/* zencod_rand.seed = meth_rand->seed ; */
@@ -776,7 +776,7 @@ static int RSA_zencod_rsa_mod_exp(BIGNUM *r0, const BIGNUM *i, RSA *rsa)
if (RSA_size(rsa) * 8 > ZENBRIDGE_MAX_KEYSIZE_RSA_CRT) {
const RSA_METHOD *meth;
- meth = RSA_PKCS1_SSLeay();
+ meth = RSA_PKCS1_OpenSSL();
return meth->rsa_mod_exp(r0, i, rsa);
} else {
zen_nb_t y, x, p, q, dmp1, dmq1, iqmp;
@@ -827,7 +827,7 @@ static int RSA_zencod_bn_mod_exp(BIGNUM *r, const BIGNUM *a, const BIGNUM *p,
if (BN_num_bits(m) > ZENBRIDGE_MAX_KEYSIZE_RSA) {
const RSA_METHOD *meth;
- meth = RSA_PKCS1_SSLeay();
+ meth = RSA_PKCS1_OpenSSL();
return meth->bn_mod_exp(r, a, p, m, ctx, m_ctx);
} else {
zen_nb_t y, x, e, n;
@@ -309,14 +309,14 @@ static int bind_helper(ENGINE *e)
# ifndef OPENSSL_NO_RSA
/*
- * We know that the "PKCS1_SSLeay()" functions hook properly to the
+ * We know that the "PKCS1_OpenSSL()" functions hook properly to the
* Zencod-specific mod_exp and mod_exp_crt so we use those functions. NB:
* We don't use ENGINE_openssl() or anything "more generic" because